@@ -41,8 +41,6 @@ static const char CONTENTMIMETYPES[] = "CONTENTMIMETYPES";
 
 static const char ROOTPARENTRID[] = "AKONADI_ROOT_COLLECTION";
 
-static const char PARENTCOLLECTIONRID[] = "ParentCollectionRid";
-static const char PARENTCOLLECTION[] = "ParentCollection";
 
 class RemoteId
 {
@@ -61,13 +59,9 @@ public:
         ridChain.append(rid);
     }
 
-    inline ~RemoteId()
-    {
-    }
-
     inline bool isAbsolute() const
     {
-        return ridChain.last() == QString::fromAscii(ROOTPARENTRID);
+        return ridChain.last() == QString::fromLatin1(ROOTPARENTRID);
     }
 
     inline bool isEmpty() const
@@ -85,7 +79,7 @@ public:
     static RemoteId rootRid;
 };
 
-RemoteId RemoteId::rootRid = RemoteId(QStringList() << QString::fromAscii(ROOTPARENTRID));
+RemoteId RemoteId::rootRid = RemoteId(QStringList() << QString::fromLatin1(ROOTPARENTRID));
 
 Q_DECLARE_METATYPE(RemoteId)
 
@@ -175,7 +169,7 @@ public:
             rid.ridChain.append(prid);
             parent = parent.parentCollection();
             if (parent == akonadiRootCollection) {
-                rid.ridChain.append(QString::fromAscii(ROOTPARENTRID));
+                rid.ridChain.append(QString::fromLatin1(ROOTPARENTRID));
                 break;
             }
         }
@@ -238,7 +232,8 @@ public:
 
                 if (matchLocalAndRemoteCollection(localCollection, removedCollection)) {
                     matched = true;
-                    localCollectionsToRemove.append(localCollection);
+                    if (!localCollection.remoteId().isEmpty())
+                        localCollectionsToRemove.append(localCollection);
                     // Remove the matched removed collection from the list so that
                     // we don't have to iterate over it again next time.
                     removedIter = removedChildren.erase(removedIter);
@@ -335,7 +330,10 @@ public:
         }
         // At this point localChildren contains collections that don't exist remotely anymore
         if (!localChildren.isEmpty() && !incremental) {
-            localCollectionsToRemove += localChildren;
+            Q_FOREACH (const auto &c, localChildren) {
+                if (!c.remoteId().isEmpty())
+                    localCollectionsToRemove.push_back(c);
+            }
         }
 
         // Recurse into children
@@ -688,7 +686,7 @@ public:
             Job *parent = (currentTransaction ? static_cast<Job *>(currentTransaction) : static_cast<Job *>(q));
             CollectionFetchJob *job = new CollectionFetchJob(akonadiRootCollection, CollectionFetchJob::Recursive, parent);
             job->fetchScope().setResource(resourceId);
-            job->fetchScope().setIncludeUnsubscribed(true);
+            job->fetchScope().setListFilter(CollectionFetchScope::NoFilter);
             job->fetchScope().setAncestorRetrieval(CollectionFetchScope::All);
             q->connect(job, SIGNAL(collectionsReceived(Akonadi::Collection::List)),
                        q, SLOT(localCollectionsReceived(Akonadi::Collection::List)));
