@@ -65,7 +65,7 @@ static QString defaultResourceId(KCoreConfigSkeleton *settings)
 
 static QString dbusServiceName()
 {
-    QString service = QString::fromLatin1("org.kde.pim.SpecialCollections");
+    QString service = QStringLiteral("org.kde.pim.SpecialCollections");
     if (ServerManager::hasInstanceIdentifier()) {
         return service + ServerManager::instanceIdentifier();
     }
@@ -99,7 +99,7 @@ static QVariant::Type argumentType(const QMetaObject *mo, const QString &method)
 /**
   @internal
 */
-class Akonadi::ResourceScanJob::Private
+class Q_DECL_HIDDEN Akonadi::ResourceScanJob::Private
 {
 public:
     Private(KCoreConfigSkeleton *settings, ResourceScanJob *qq);
@@ -329,8 +329,8 @@ void DefaultResourceJobPrivate::resourceCreateResult(KJob *job)
     {
         agent.setName(mDefaultResourceOptions.value(QStringLiteral("Name")).toString());
 
-        QDBusInterface conf(QString::fromLatin1("org.freedesktop.Akonadi.Resource.") + defaultId,
-                            QString::fromLatin1("/Settings"), QString());
+        QDBusInterface conf(QLatin1String("org.freedesktop.Akonadi.Resource.") + defaultId,
+                            QStringLiteral("/Settings"), QString());
 
         if (!conf.isValid()) {
             q->setError(-1);
@@ -347,7 +347,7 @@ void DefaultResourceJobPrivate::resourceCreateResult(KJob *job)
                 continue;
             }
 
-            const QString methodName = QString::fromLatin1("set%1").arg(it.key());
+            const QString methodName = QStringLiteral("set%1").arg(it.key());
             const QVariant::Type argType = argumentType(conf.metaObject(), methodName);
             if (argType == QVariant::Invalid) {
                 q->setError(Job::Unknown);
@@ -553,7 +553,7 @@ void DefaultResourceJob::slotResult(KJob *job)
 
 // ===================== GetLockJob ============================
 
-class Akonadi::GetLockJob::Private
+class Q_DECL_HIDDEN Akonadi::GetLockJob::Private
 {
 public:
     Private(GetLockJob *qq);
@@ -601,6 +601,8 @@ void GetLockJob::Private::doStart()
 
 void GetLockJob::Private::serviceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner)
 {
+    Q_UNUSED(oldOwner)
+
     if (newOwner.isEmpty()) {
         const bool gotIt = KDBusConnectionPool::threadConnection().registerService(dbusServiceName());
         if (gotIt) {
