@@ -27,7 +27,6 @@
 #include "vectorhelper.h"
 
 #include <KLocalizedString>
-#include <KMessageBox>
 
 #include "agentmanager.h"
 #include "agenttype.h"
@@ -48,9 +47,10 @@
 #include <akonadi/private/protocol_p.h>
 
 #include <qdebug.h>
+#include <QMessageBox>
 #include <QtGui/QIcon>
 
-QMap<KJob *, QTime> jobTimeTracker;
+QHash<KJob *, QTime> jobTimeTracker;
 
 Q_LOGGING_CATEGORY(DebugETM, "org.kde.akonadi.ETM")
 
@@ -152,15 +152,6 @@ void EntityTreeModelPrivate::init(ChangeRecorder *monitor)
     Akonadi::ServerManager *serverManager = Akonadi::ServerManager::self();
     q->connect(serverManager, SIGNAL(started()), SLOT(serverStarted()));
 
-    QHash<int, QByteArray> names = q->roleNames();
-
-    names.insert(EntityTreeModel::UnreadCountRole, "unreadCount");
-    names.insert(EntityTreeModel::FetchStateRole, "fetchState");
-    names.insert(EntityTreeModel::CollectionSyncProgressRole, "collectionSyncProgress");
-    names.insert(EntityTreeModel::ItemIdRole, "itemId");
-
-    q->setRoleNames(names);
-
     fillModel();
 }
 
@@ -277,25 +268,11 @@ void EntityTreeModelPrivate::fetchCollections(const Collection &collection, Coll
     fetchCollections(job);
 }
 
-// Specialization needs to be in the same namespace as the definition
 namespace Akonadi
 {
 
-template<>
-bool EntityTreeModelPrivate::isHidden<Akonadi::Collection>(const Akonadi::Collection &entity) const
-{
-    return isHidden(entity, Node::Collection);
-}
-
-template<>
-bool EntityTreeModelPrivate::isHidden<Akonadi::Item>(const Akonadi::Item &entity) const
-{
-    return isHidden(entity, Node::Item);
-}
-
-}
-
-bool EntityTreeModelPrivate::isHidden(const Entity &entity, Node::Type type) const
+template<typename T>
+inline bool EntityTreeModelPrivate::isHiddenImpl(const T &entity, Node::Type type) const
 {
     if (m_showSystemEntities) {
         return false;
@@ -306,18 +283,32 @@ bool EntityTreeModelPrivate::isHidden(const Entity &entity, Node::Type type) con
         return false;
     }
 
-    if (entity.hasAttribute<EntityHiddenAttribute>()) {
+    // entity.hasAttribute<EntityHiddenAttribute>() does not compile w/ GCC for
+    // some reason
+    if (entity.hasAttribute(EntityHiddenAttribute().type())) {
         return true;
     }
 
     const Collection parent = entity.parentCollection();
     if (parent.isValid()) {
-        return isHidden(parent, Node::Collection);
+        return isHiddenImpl(parent, Node::Collection);
     }
 
     return false;
 }
 
+}
+
+bool EntityTreeModelPrivate::isHidden(const Akonadi::Collection &collection) const
+{
+    return isHiddenImpl(collection, Node::Collection);
+}
+
+bool EntityTreeModelPrivate::isHidden(const Akonadi::Item &item) const
+{
+    return isHiddenImpl(item, Node::Item);
+}
+
 void EntityTreeModelPrivate::collectionListFetched(const Akonadi::Collection::List &collections)
 {
     QVectorIterator<Akonadi::Collection> it(collections);
@@ -344,10 +335,10 @@ void EntityTreeModelPrivate::collectionListFetched(const Akonadi::Collection::Li
 static QSet<Collection::Id> getChildren(Collection::Id parent, const QHash<Collection::Id, Collection::Id> &childParentMap)
 {
     QSet<Collection::Id> children;
-    Q_FOREACH (Collection::Id c, childParentMap.keys()) {
-        if (childParentMap.value(c) == parent) {
-            children << c;
-            children += getChildren(c, childParentMap);
+    for (auto it = childParentMap.cbegin(), e = childParentMap.cend(); it != e; ++it) {
+        if (it.value() == parent) {
+            children << it.key();
+            children += getChildren(it.key(), childParentMap);
         }
     }
     return children;
@@ -418,11 +409,11 @@ void EntityTreeModelPrivate::collectionsFetched(const Akonadi::Collection::List
         QSet<Collection::Id> parents;
 
         //Find toplevel parents of the subtrees
-        Q_FOREACH (Collection::Id c, childParentMap.keys()) {
+        for (auto it = childParentMap.cbegin(), e = childParentMap.cend(); it != e; ++it) {
             //The child has a parent without parent (it's a toplevel node that is not yet in m_collections)
-            if (!childParentMap.contains(childParentMap.value(c))) {
-                Q_ASSERT(!m_collections.contains(c));
-                parents << c;
+            if (!childParentMap.contains(it.value())) {
+                Q_ASSERT(!m_collections.contains(it.key()));
+                parents << it.key();
             }
         }
 
@@ -1349,12 +1340,8 @@ void EntityTreeModelPrivate::itemFetchJobDone(KJob *job)
         return;
     }
     ItemFetchJob *iJob = static_cast<ItemFetchJob *>(job);
-
     qCDebug(DebugETM) << "Fetch job took " << jobTimeTracker.take(job).elapsed() << "msec";
-    qCDebug(DebugETM) << "was item fetch job: items:" << iJob->items().size();
-    if (!iJob->items().isEmpty()) {
-        qCDebug(DebugETM) << "first item collection:" << iJob->items().at(0).parentCollection().name();
-    }
+    qCDebug(DebugETM) << "was item fetch job: items:" << iJob->count();
 
     if (!iJob->count()) {
         m_collectionsWithoutItems.insert(collectionId);
@@ -1394,7 +1381,7 @@ void EntityTreeModelPrivate::pasteJobDone(KJob *job)
 
         errorMsg += QLatin1Char(' ') + job->errorString();
 
-        KMessageBox::error(0, errorMsg);
+        QMessageBox::critical(0, i18n("Error"), errorMsg);
     }
 }
 
@@ -1741,8 +1728,8 @@ QModelIndex EntityTreeModelPrivate::indexForCollection(const Collection &collect
     } else if (collection.parentCollection().isValid()) {
         parentId = collection.parentCollection().id();
     } else {
-        QHash<Entity::Id, QList<Node *> >::const_iterator it = m_childEntities.constBegin();
-        const QHash<Entity::Id, QList<Node *> >::const_iterator end = m_childEntities.constEnd();
+        QHash<Node::Id, QList<Node *> >::const_iterator it = m_childEntities.constBegin();
+        const QHash<Node::Id, QList<Node *> >::const_iterator end = m_childEntities.constEnd();
         for (; it != end; ++it) {
             const int row = indexOf<Node::Collection>(it.value(), collection.id());
             if (row < 0) {
@@ -1785,6 +1772,7 @@ QModelIndexList EntityTreeModelPrivate::indexesForItem(const Item &item) const
 
     const Collection::List collections = getParentCollections(item);
 
+    indexes.reserve(collections.size());
     foreach (const Collection &collection, collections) {
         const int row = indexOf<Node::Item>(m_childEntities.value(collection.id()), item.id());
         Q_ASSERT(row >= 0);
@@ -1873,7 +1861,8 @@ void EntityTreeModelPrivate::fillModel()
         emit q_ptr->collectionTreeFetched(collections);     // there are no collections to fetch
 
         Item::List items;
-        foreach (Entity::Id id, m_monitor->itemsMonitoredEx()) {
+        items.reserve(m_monitor->itemsMonitoredEx().size());
+        Q_FOREACH (Item::Id id, m_monitor->itemsMonitoredEx()) {
             items.append(Item(id));
         }
         ItemFetchJob *itemFetch = new ItemFetchJob(items, m_session);
